@@ -7,7 +7,7 @@ from urllib.parse import urlparse
 from .image import url2mime
 
 
-__version__ = '0.7.5'
+__version__ = '0.7.6'
 
 renderers: Dict = {}
 
@@ -67,7 +67,7 @@ class config:
 
 class Text(BaseNode):
     type = "text"
-    mark_tags = {"bold": "strong", "italic": "em", "link": "a"}
+    mark_tags = {"bold": "strong", "italic": "em", "link": "a", "sup": "sup"}
 
     def inner_render(self, node):
         text = e(node["text"])
@@ -82,7 +82,9 @@ class Text(BaseNode):
                         if not is_trusted_link(url):
                             attrs["target"] = "_blank"
                             attrs["rel"] = "noopener nofollow"
-                    attrs_s = " ".join(f'{k}="{e(v)}"' for k, v in attrs.items())
+                    attrs_s = " ".join(
+                        f'{k}="{e(v)}"' for k, v in attrs.items()
+                    )
                     text = f"<{tag} {attrs_s}>{text}</{tag}>"
                 else:
                     text = f"<{tag}>{text}</{tag}>"
@@ -151,6 +153,13 @@ class Paragraph(BaseContainer):
     type = "paragraph"
     wrap_tag: str = "p"
 
+    def is_renderable(self, node):
+        text = ''
+        content = node.get('content', [])
+        if content:
+            text = content[0].get('text', '')
+        return bool(text)
+
 
 class BlockQuote(BaseContainer):
     type = "blockquote"
